#### Aplikace spotebn funkce na R ####
#
# Jaroslav Poncar
#
## Kapitola 2.1 Analza tvrtletnch dat
#
# R 1999Q1 - 2016Q4 (tvrtletn data)
# seznn neoitn data
# v cench roku 2010
#
# vdaje na konenou spotebu domcnost (mil. K)
# disponibiln dchod domcnost (mil. K)
# bohatstv (ist aktiva) domcnost (mil. K)
#
rm(list=ls())
data <- read.csv("cr_data.csv")
CR <- ts(data, start=c(1999,1), frequency = 4)
CR
#
# Graf spoteby a disponibilnho dchodu
plot.new()
plot.window(xlim=c(1998,2017), ylim=c(340000,600000))
axis(1)
axis(2)
box()
lines(CR[ , "consumption"],col="blue")
lines(CR[ , "income"],col="red")
legend("topleft", c("Disponibiln dchod","Spoteba"), 
       lty=c(1,1), 
       lwd=c(2,2),col=c("red","blue"))
#
########################################################################################
#
## Oitn dat od seznnosti ##
#
# Spoteba - seznn oitn
#
# Seznn oitn pomoc klouzavch prmr #
# ?decompose
cons.d <- decompose(CR[ , "consumption"])
consumption_MA <- ts(cons.d$trend, start=c(1999,1), frequency = 4) # trendov sloka
##
# Seznn oitn pomoc X-12-ARIMA #
require(stringi) # install.packages("stringi")
require(x12) # install.packages("x12")
# ?x12
x12path("c:/x12/x12a.exe") # cesta k programu x12a.exe
# ke staen na: http://www.census.gov/ts/TSMS/WIX12/winx12.zip
#
consx12 <- ts(CR[ , "consumption"], start=c(1999,1), frequency = 4)
cons.x <- new("x12Single",ts=consx12,tsName="cons")
cons.x <- x12(cons.x)
summary(cons.x)
consumption_X12 <- cons.x@x12Output@d11
#
#
# Disponibiln dchod - seznn oitn
#
# Seznn oitn pomoc klouzavch prmr #
inc.d <- decompose(CR[ ,"income"])
income_MA <- ts(inc.d$trend, start=c(1999,1), frequency = 4) # trendov sloka
#
# Seznn oitn pomoc X-12-ARIMA #
incx12 <- ts(CR[ , "income"], start=c(1999,1), frequency = 4)
inc.x <- new("x12Single",ts=incx12,tsName="inc")
inc.x <- x12(inc.x)
summary(inc.x)
income_X12 <- inc.x@x12Output@d11
#
# Graf seznn neoitnch a oitnch ad
CR.2 <- cbind(CR, consumption_MA, consumption_X12, income_MA, income_X12)
plot.ts(CR.2[ , c(1,3,4,2,5,6)])
#
########################################################################################
#
## ADF a kointegran testy
## 
##    A) Jsou ady stacionrn?
##
require(urca) # install.packages("urca")
# H0: asov ada m jednotkov koen
consumption_MA.cc <- na.omit(consumption_MA) # pln data
# ADF test
summary(ur.df(consumption_MA.cc, type="none", selectlags="BIC"))
summary(ur.df(consumption_MA.cc, type="drift", selectlags="BIC"))
summary(ur.df(consumption_MA.cc, type="trend", selectlags="BIC"))
# decompose: ada je nestacionrn
#
consumption_X12.cc <- na.omit(consumption_X12) # pln data
# H0: asov ada m jednotkov koen
# ADF test
summary(ur.df(consumption_X12.cc, type="none", selectlags="BIC"))
summary(ur.df(consumption_X12.cc, type="drift", selectlags="BIC"))
summary(ur.df(consumption_X12.cc, type="trend", selectlags="BIC"))
# x12: ada je nestacionrn
#
income_MA.cc <- na.omit(income_MA) # pln data
# H0: asov ada m jednotkov koen
# ADF test
summary(ur.df(income_MA.cc, type="none", selectlags="BIC"))
summary(ur.df(income_MA.cc, type="drift", selectlags="BIC"))
summary(ur.df(income_MA.cc, type="trend", selectlags="BIC"))
# decompose: ada je nestacionrn
#
income_X12.cc <- na.omit(income_X12) # pln data
# H0: asov ada m jednotkov koen
# ADF test
summary(ur.df(income_X12.cc, type="none", selectlags="BIC"))
summary(ur.df(income_X12.cc, type="drift", selectlags="BIC"))
summary(ur.df(income_X12.cc, type="trend", selectlags="BIC"))
# x12: ada je nestacionrn
#
## Jak je d integrace asov ady? [I(0), I(1), ...]
#
# Prvn diference - spoteba
summary(ur.df(diff(consumption_MA.cc), type="none", selectlags="BIC"))
summary(ur.df(diff(consumption_MA.cc), type="drift", selectlags="BIC"))
summary(ur.df(diff(consumption_MA.cc), type="trend", selectlags="BIC"))
# decompose: ada nen integrovna du 1: I(1)
summary(ur.df(diff(consumption_X12.cc), type="none", selectlags="BIC"))
summary(ur.df(diff(consumption_X12.cc), type="drift", selectlags="BIC"))
summary(ur.df(diff(consumption_X12.cc), type="trend", selectlags="BIC"))
# x12: ada je integrovna du 1: I(1)
#
# Prvn diference - dchod
summary(ur.df(diff(income_MA.cc), type="none", selectlags="BIC"))
summary(ur.df(diff(income_MA.cc), type="drift", selectlags="BIC"))
summary(ur.df(diff(income_MA.cc), type="trend", selectlags="BIC"))
# decompose: ada nen integrovna du 1: I(1)
summary(ur.df(diff(income_X12.cc), type="none", selectlags="BIC"))
summary(ur.df(diff(income_X12.cc), type="drift", selectlags="BIC"))
summary(ur.df(diff(income_X12.cc), type="trend", selectlags="BIC"))
# x12: ada je integrovna du 1: I(1)
#
#
##    B) Jsou ady kointegrovan?  
#
CR.m <- cbind(consumption_MA, income_MA)
CR2.m <- cbind(consumption_X12, income_X12)
#
## I.   Phillips & Ouliaris kointegran test
#  H0: ady nejsou kointegrovan
CR.po <- ca.po(CR.m, lag="long", type="Pz")
summary(CR.po) 
# decompose: nezamtme H0
CR2.po <- ca.po(CR2.m, lag="long", type="Pz")
summary(CR2.po)
# x12: zamtme H0
CR.po <- ca.po(CR.m, lag="long", type="Pz", demean="trend")
summary(CR.po) 
# decompose: nezamtme H0
CR2.po <- ca.po(CR2.m, lag="long", type="Pz", demean="trend")
summary(CR2.po)
# x12: nezamtme H0
#
#
require(lmtest) #install.packages("lmtest")
#
## II.  Newbold-Grangerovo pravidlo palce
#
# pokud R^2 > DW-d  -> Riziko zdnliv regrese (ady nejsou kointegrovan)
#
# NEWBOLD-GRANGER rule of thumb evaluation 
NGRT <- function(model) {
  require(lmtest)
  R2 <- summary(model)$r.squared
  DW <- dwtest(model)$statistic
  if (R2 == "NULL") return("Zkontrolujte specifikaci modelu")
  if (DW == "NULL") return("Zkontrolujte specifikaci modelu")
  NGRT <- (R2 > DW)
  if (NGRT == T) {
    return("Newbold-Grangerovo pravidlo indikuje zdnlivou regresi!")
  }
  if (NGRT == F) {
    return("Newbold-Grangerovo pravidlo neindikuje zdnlivou regresi.")
  }
  else return("Zkontrolujte specifikaci modelu") 
}
#
CR.fit <- lm(consumption_MA ~ income_MA, data = CR.m)
NGRT(CR.fit)
# decompose: Newbold-Grangerovo pravidlo indikuje zdnlivou regresi!
#
CR2.fit <- lm(consumption_X12 ~ income_X12, data = CR.m)
NGRT(CR2.fit)
# x12: Newbold-Grangerovo pravidlo neindikuje zdnlivou regresi.
#
#
## III.  Cointegration Regression Durbin Watson test (CRDW)
#
#  H0: DW-d = 0, tzn. ady nejsou kointegrovan
#  H1: DW-d != 0, ady jsou kointegrovan (autokorelace je mon)
#
#  pro alpha = 5%, zamtme H0, pokud je pekroena kritick hodnota 0.386.
#
dwtest(CR.fit)$statistic 
# decompose: Nezamtme H0.
#
dwtest(CR2.fit)$statistic
# x12: ady jsou kointegrovan (mon autokorelace)
#
#
## IV.  Engle - Granger test stacionarity rezidu
#
#  H0: rezidua nejsou stacionrn, tzn. ady nejsou kointegrovan
#  H1: non(H0)
#
summary(CR.fit)
CR.resids <- CR.fit$residuals 
head(CR.resids)
summary(ur.df(CR.resids, type="none", selectlags="BIC"))
summary(ur.df(CR.resids, type="drift", selectlags="BIC"))
summary(ur.df(CR.resids, type="trend", selectlags="BIC"))
# decompose: Zamtme H0
#
summary(CR2.fit)
CR2.resids <- CR2.fit$residuals 
head(CR2.resids)
summary(ur.df(CR2.resids, type="none", selectlags="BIC"))
summary(ur.df(CR2.resids, type="drift", selectlags="BIC"))
summary(ur.df(CR2.resids, type="trend", selectlags="BIC"))
# x12: Zamtme H0
#
#
########################################################################################
#
## 2.1.2 Prmrn sklon ke spoteb (APC) a mezn sklon ke spoteb (MPC)
#
## APC
APC <- consumption_X12/income_X12
APC
plot(APC)
#
## MPC
MPC <- diff(consumption_X12)/diff(income_X12)
MPC
plot(MPC)
#
plot(MPC,col="blue")
lines(APC,col="red")
legend(1999,10, # places a legend at the appropriate place 
       c("MPC","APC"), # puts text in the legend
       lty=c(1,1), # gives the legend appropriate symbols (lines)
       lwd=c(2,2),col=c("blue","red"))
#
##
########################################################################################