#### Aplikace spotebn funkce na R ####
#
# Jaroslav Poncar
#
## Kapitola 2 Aplikace spotebn funkce (2.2 - 2.9)
#
# R 1999Q1 - 2016Q4 (tvrtletn data)
# seznn oitn data
# v cench roku 2010
#
# vdaje na konenou spotebu domcnost (mil. K)
# disponibiln dchod domcnost (mil. K)
# bohatstv (ist aktiva) domcnost (mil. K, 2008Q1 - 2016Q2)
# inflace (%)
# mra nezamstnanosti (%)
# CPI (%, 2015=100)
# prmrn 3-msn rokov mra (%, 1999Q1 - 2015Q3)
# penn zsoba M2 (mil. K, 2002Q1 - 2016Q4)
#
rm(list=ls())
data <- read.csv("cr_data_all.csv")
CR <- ts(data, start=c(1999,1), frequency = 4)
CR
#
# Extrahovn promnnch pro jednodu prci s modely
consumption <- CR[ , "consumption"]
income <- CR[ , "income"]
#
########################################################################################
#
# 2.2 Aplikace keynesinsk funkce spoteby (Hypotza absolutnho dchodu)
#
#..Odhad (1.1)..Vsledky (2.1)..Ploha (5-15)
sf_abs <- lm(consumption ~ income)
summary(sf_abs)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_abs) # DW = 1.2735, p-value = 0.0004338
#
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_abs, order=1) # LM test = 8.8985, df = 1, p-value = 0.002854
bgtest(sf_abs, order=3) # LM test = 13.153, df = 3, p-value = 0.004317
#
# Jarque-Bera test normality rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_abs$residuals) # X-squared = 2.7619, df = 2, p-value = 0.2513
# 
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_abs, studentize = F) # BP = 0.11637, df = 1, p-value = 0.733
#
########################################################################################
#
# 2.3 Aplikace hypotzy relativnho dchodu 
# + 
# 2.5 Aplikace hypotzy permanentnho dchodu
#
require(dyn) # install.packages("dyn")
#..Odhad (1.3)..Vsledky (2.2)..Ploha (5-16)
#..Odhad (1.15/1.18)..Vsledky (2.6)..Ploha (5-16)
sf_rel <- dyn$lm(consumption ~ income + lag(consumption, -1))
summary(sf_rel)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rel) # DW = 1.6028, p-value = 0.02996
#
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rel, order=1) # LM test = 2.8147, df = 1, p-value = 0.09341
bgtest(sf_rel, order=3) # LM test = 6.3109, df = 3, p-value = 0.09743
#
# Jarque-Bera test normality rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rel$residuals) # X-squared = 0.18645, df = 2, p-value = 0.911
# 
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rel, studentize = F) # BP = 2.2481, df = 2, p-value = 0.325
#
########################################################################################
#
# 2.6 Aplikace teorie racionlnch oekvn
#
# Omezen potu pozorovn kvli promnn bohatstv
consumption.w <- window(consumption, start=c(2008,1), end=c(2016,2))
income.w <- window(income, start=c(2008,1), end=c(2016,2))
wealth <- window(CR[ , "wealth"], start=c(2008,1), end=c(2016,2))
#
## Prvn rovnice:
#..Odhad (1.22)..Vsledky (2.9)..Ploha (5-17)
sf_rat1 <- dyn$lm(income.w ~ lag(income.w, -1) + lag(wealth, -1))
summary(sf_rat1)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rat1) # DW = 2.5157, p-value = 0.8834
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rat1, order=1) # LM test = 4.1135, df = 1, p-value = 0.04254
bgtest(sf_rat1, order=3) # LM test = 8.9399, df = 3, p-value = 0.0301
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rat1$residuals) # X-squared = 8.4169, df = 2, p-value = 0.01487
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rat1, studentize = F) # BP = 0.76884, df = 2, p-value = 0.6808
#
## Druh rovnice:
income.fit <- sf_rat1$fitted.values
#
# Omezen potu pozorovn kvli vyrovnanm hodnotm dchodu
consumption.w2 <- window(consumption, start=c(2008,2), end=c(2016,2))
# Zatek vyrovnanch hodnot 2008Q2
income_fit <- ts(income.fit, start=c(2008,2), frequency = 4)
#
#..Odhad (1.21)..Vsledky (2.10)..Ploha (5-18)
sf_rat2 <- dyn$lm(consumption ~ income_fit)
summary(sf_rat2)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rat2) # DW = 1.1307, p-value = 0.002278
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rat2, order=1) # LM test = 5.5932, df = 1, p-value = 0.01803
bgtest(sf_rat2, order=3) # LM test = 6.7062, df = 3, p-value = 0.08187
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rat2$residuals) # X-squared = 0.39374, df = 2, p-value = 0.8213
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rat2, studentize = F) # BP = 0.79309, df = 1, p-value = 0.3732
#
#
# 2.6.2 REPIH
#
#..Odhad (1.26)..Vsledky (2.11)..Ploha (5-19)
sf_rat3 <- dyn$lm(consumption ~ lag(consumption, -1))
summary(sf_rat3)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rat3) # DW = 1.6023, p-value = 0.03409
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rat3, order=1) # LM test = 2.6199, df = 1, p-value = 0.1055
bgtest(sf_rat3, order=3) # LM test = 5.5025, df = 3, p-value = 0.1385
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rat3$residuals) # X-squared = 0.51568, df = 2, p-value = 0.7727
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rat3, studentize = F) # BP = 1.8128, df = 1, p-value = 0.1782
#
#..Odhad (1.27)
lr_rat4 <- dyn$lm(consumption ~ lag(consumption, -1) + lag(consumption, -2) + lag(consumption, -3) + lag(consumption, -4) + lag(consumption, -5) + lag(consumption, -6) + lag(consumption, -7) + lag(consumption, -8) + lag(consumption, -9) + lag(consumption, -10))
summary(lr_rat4)
#..Odhad (1.28)
lr_rat5 <- dyn$lm(consumption ~ lag(consumption, -1) + lag(income, -1) + lag(income, -2) + lag(income, -3) + lag(income, -4) + lag(income, -5) + lag(income, -6) + lag(income, -7) + lag(income, -8) + lag(income, -9) + lag(income, -10))
summary(lr_rat5)
#
#####################################################################################################################################################################################################################################################################
#
# 2.7 Aplikace mechanismu korekce chyby
# 
# model DHSY
#
#..Odhad (1.37)..Vsledky (2.12)..Ploha (5-20)
sf_dhsy <- dyn$lm(log(consumption) ~ log(income) + lag(log(income), -1) + lag(log(consumption), -1))
summary(sf_dhsy)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_dhsy) # DW = 1.633, p-value = 0.04095
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_dhsy, order=1) # LM test = 3.251, df = 1, p-value = 0.07138
bgtest(sf_dhsy, order=3) # LM test = 6.8575, df = 3, p-value = 0.07658
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_dhsy$residuals) # X-squared = 0.3176, df = 2, p-value = 0.8532
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_dhsy, studentize = F) # BP = 0.74637, df = 3, p-value = 0.8622
#
# model HUS
#
# Omezen potu pozorovn kvli promnn bohatstv
consumption.w <- window(consumption, start=c(2008,1), end=c(2016,2))
income.w <- window(income, start=c(2008,1), end=c(2016,2))
# Rozdl spoteby a dchodu
cons_inc <- lag(log(consumption.w), -1) - lag(log(income.w), -1)
# Rozdl bohatstv a dchodu
weal_inc <- lag(log(wealth), -1) - lag(log(income.w), -1)
#
#..Odhad (1.41)..Vsledky (2.13)..Ploha (5-21)
sf_hus <- dyn$lm(diff(log(consumption.w)) ~ diff(log(income.w)) + cons_inc + weal_inc)
summary(sf_hus)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_hus) # DW = 1.3807, p-value = 0.01717
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_hus, order=1) # LM test = 1.0782, df = 1, p-value = 0.2991
bgtest(sf_hus, order=3) # LM test = 2.7897, df = 3, p-value = 0.4252
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_hus$residuals) # X-squared = 11.069, df = 2, p-value = 0.003949
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_hus, studentize = F) # BP = 7.95, df = 3, p-value = 0.04706
#
##################################################################################################################################################
#
# 2.9 Nvrh empirickho modelu funkce spoteby pro R
#
# Omezen potu pozorovn kvli promnn bohatstv
consumption <- window(consumption, start=c(2008,1), end=c(2016,2))
income <- window(income, start=c(2008,1), end=c(2016,2))
inflation <- window(CR[ , "inflation"], start=c(2008,1), end=c(2016,2))
unemployment <- window(CR[ , "unemployment"], start=c(2008,1), end=c(2016,2))
CPI <- window(CR[ , "CPI"], start=c(2008,1), end=c(2016,2))
m3_rate <- window(CR[ , "X3.month_rates"], start=c(2008,1), end=c(2016,2))
time <- ts(c(1:34), start=c(2008,1), frequency = 4)
#
#..Vsledky (2.15)..Ploha (5-22)
sf_my1 <- dyn$lm(consumption ~ income + unemployment + time)
summary(sf_my1)
#..Vsledky (2.16)..Ploha (5-23)
sf_my2 <- dyn$lm(consumption ~ income + unemployment + wealth)
summary(sf_my2)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_my1) # DW = 1.9567, p-value = 0.2512
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_my1, order=1) # LM test = 0.031309, df = 1, p-value = 0.8596
bgtest(sf_my1, order=3) # LM test = 1.9421, df = 3, p-value = 0.5845
# Ramsey's RESET test
reset(sf_my1, power = 2:3, type="fitted") # RESET = 1.8767, df1 = 2, df2 = 28, p-value = 0.1719
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_my1$residuals) # X-squared = 0.44361, df = 2, p-value = 0.8011
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_my1, studentize = F) # BP = 7.5814, df = 3, p-value = 0.0555
#
##################################################################################################################################################
#
# 4.2.1 Vbr modelu pro predikci spoteby
#
# Statisticky nejvznamj modely:
summary(sf_rel) # (2.6)
summary(sf_rat3) # (2.11)
summary(sf_my1) # (2.15)
summary(sf_my2) # (2.16)
# AIC a BIC (Pi pouit stejnho potu pozorovn)
AIC(sf_my1,sf_my2,sf_rel,sf_rat3)
BIC(sf_my1,sf_my2,sf_rel,sf_rat3)
#
# Nejvhodnj model sf_my1 (2.15)
#
##
########################################################################################