#### Aplikace spotebn funkce na R ####
#
# Jaroslav Poncar
#
## Kapitola 3 Srovnn SF ped a po krizi 2008 - 2009
#
# R 1999Q1 - 2016Q4 (tvrtletn data)
# seznn oitn data
# v cench roku 2010
#
# vdaje na konenou spotebu domcnost (mil. K)
# disponibiln dchod domcnost (mil. K)
# bohatstv (ist aktiva) domcnost (mil. K, 2008Q1 - 2016Q2)
# inflace (%)
# mra nezamstnanosti (%)
# CPI (%, 2015=100)
# prmrn 3-msn rokov mra (%, 1999Q1 - 2015Q3)
# penn zsoba M2 (mil. K, 2002Q1 - 2016Q4)
#
rm(list=ls())
data <- read.csv("cr_data_all.csv")
CR <- ts(data, start=c(1999,1), frequency = 4)
CR
#
# Rozdlen asovch ad na obdob ped (1) a po krizi (2)
consumption_1 <- window(CR[ , "consumption"], start=c(1999,1), end=c(2008,2)) # obdob ped hosp. kriz
consumption_2 <- window(CR[ , "consumption"], start=c(2009,3), end=c(2016,4)) # obdob po hosp. krizi
income_1 <- window(CR[ , "income"], start=c(1999,1), end=c(2008,2)) # obdob ped hosp. kriz
income_2 <- window(CR[ , "income"], start=c(2009,3), end=c(2016,4)) # obdob po hosp. krizi
#
########################################################################################
#
# 3.2.1 Analza keynesinsk funkce spoteby (Hypotza absolutnho dchodu)
#
#..Odhad (1.1)..Vsledky (3.1/3.2)
sf_abs <- lm(consumption_1 ~ income_1) # obdob ped hosp. kriz
sf_abs <- lm(consumption_2 ~ income_2) # obdob po hosp. krizi
summary(sf_abs)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_abs)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_abs, order=1)
bgtest(sf_abs, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_abs$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_abs, studentize = F)
#
########################################################################################
#
# 3.2.2 Analza hypotzy relativnho dchodu 
# + 
# 3.2.3 Analza hypotzy permanentnho dchodu
#
#..Odhad (1.3)..Vsledky (3.3/3.4)
#..Odhad (1.15/1.18)..Vsledky (3.7/3.8)
require(dyn) # install.packages("dyn")
# The long-term consumption behaviour in the CR:
sf_rel <- dyn$lm(consumption_1 ~ income_1 + lag(consumption_1, -1)) # obdob ped hosp. kriz
sf_rel <- dyn$lm(consumption_2 ~ income_2 + lag(consumption_2, -1)) # obdob po hosp. krizi
summary(sf_rel)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rel)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rel, order=1)
bgtest(sf_rel, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rel$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rel, studentize = F)
#
########################################################################################
#
# 3.2.4 Analza teorie racionlnch oekvn
#
m2 <- CR[ , "m2"]
# Seznn oitn pomoc X-12-ARIMA #
require(stringi) # install.packages("stringi")
require(x12) # install.packages("x12")
x12path("c:/x12/x12a.exe") # cesta k programu x12a.exe
# ke staen na: http://www.census.gov/ts/TSMS/WIX12/winx12.zip
m2x12 <- ts(m2, start=c(2002,1), frequency = 4)
m2.x <- new("x12Single",ts=m2x12,tsName="m2")
m2.x <- x12(m2.x)
summary(m2.x)
m2 <- m2.x@x12Output@d11
#
consumption.m_1 <- window(CR[ , "consumption"], start=c(2002,1), end=c(2008,2)) # obdob ped hosp. kriz
income.m_1 <- window(CR[ , "income"], start=c(2002,1), end=c(2008,2)) # obdob ped hosp. kriz
m2_1 <- window(m2, start=c(2002,1), end=c(2008,2)) # obdob ped hosp. kriz
m2_2 <- window(m2, start=c(2009,3), end=c(2016,4)) # obdob po hosp. krizi
#
## Prvn rovnice: 
#..Odhad (1.22)..Vsledky (3.9/3.10)
sf_rat1 <- dyn$lm(income.m_1 ~ lag(income.m_1, -1) + lag(m2_1, -1)) # obdob ped hosp. kriz
sf_rat1 <- dyn$lm(income_2 ~ lag(income_2, -1) + lag(m2_2, -1)) # obdob po hosp. krizi
summary(sf_rat1)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rat1)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rat1, order=1)
bgtest(sf_rat1, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rat1$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rat1, studentize = F)
#
## Druh rovnice:
income_fit <- sf_rat1$fitted.values
#
consumption.2m_1 <- window(CR[ , "consumption"], start=c(2002,2), end=c(2008,2)) # obdob ped hosp. kriz
income_fit2 <- ts(income_fit, start=c(2002,2), frequency = 4) # obdob ped hosp. kriz
income_fit2 <- ts(income_fit, start=c(2009,3), frequency = 4) # obdob po hosp. krizi
#
#..Odhad (1.21)..Vsledky (3.11/3.12)
sf_rat2 <- dyn$lm(consumption.2m_1 ~ income_fit2) # obdob ped hosp. kriz
sf_rat2 <- dyn$lm(consumption_2 ~ income_fit2) # obdob po hosp. krizi
summary(sf_rat2)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rat2)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rat2, order=1)
bgtest(sf_rat2, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rat2$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rat2, studentize = F)
#
########################################################################################
#
# 3.2.5 REPIH
#
#..Odhad (1.26)..Vsledky (3.13/3.14)
sf_rat3 <- dyn$lm(consumption_1 ~ lag(consumption_1, -1)) # obdob ped hosp. kriz
sf_rat3 <- dyn$lm(consumption_2 ~ lag(consumption_2, -1)) # obdob po hosp. krizi
summary(sf_rat3)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_rat3)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_rat3, order=1)
bgtest(sf_rat3, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_rat3$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_rat3, studentize = F)
#
#..Odhad (1.27)
# obdob ped hosp. kriz
sf_rat4 <- dyn$lm(consumption_1 ~ lag(consumption_1, -1) + lag(consumption_1, -2) + lag(consumption_1, -3) + lag(consumption_1, -4) + lag(consumption_1, -5) + lag(consumption_1, -6) + lag(consumption_1, -7) + lag(consumption_1, -8) + lag(consumption_1, -9) + lag(consumption_1, -10))
# obdob po hosp. krizi
sf_rat4 <- dyn$lm(consumption_2 ~ lag(consumption_2, -1) + lag(consumption_2, -2) + lag(consumption_2, -3) + lag(consumption_2, -4) + lag(consumption_2, -5) + lag(consumption_2, -6) + lag(consumption_2, -7) + lag(consumption_2, -8) + lag(consumption_2, -9) + lag(consumption_2, -10))
summary(sf_rat4)
#..Odhad (1.28)
# obdob ped hosp. kriz
sf_rat5 <- dyn$lm(consumption_1 ~ lag(consumption_1, -1) + lag(income_1, -1) + lag(income_1, -2) + lag(income_1, -3) + lag(income_1, -4) + lag(income_1, -5) + lag(income_1, -6) + lag(income_1, -7) + lag(income_1, -8) + lag(income_1, -9) + lag(income_1, -10))
# obdob po hosp. krizi
sf_rat5 <- dyn$lm(consumption_2 ~ lag(consumption_2, -1) + lag(income_2, -1) + lag(income_2, -2) + lag(income_2, -3) + lag(income_2, -4) + lag(income_2, -5) + lag(income_2, -6) + lag(income_2, -7) + lag(income_2, -8) + lag(income_2, -9) + lag(income_2, -10))
summary(sf_rat5)
#
########################################################################################
#
# 3.2.6 DHSY
#
#..Odhad (1.37)..Vsledky (3.15/3.17)
# obdob ped hosp. kriz
sf_dhsy <- dyn$lm(log(consumption_1) ~ log(income_1) + lag(log(income_1), -1) + lag(log(consumption_1), -1))
# obdob po hosp. krizi
sf_dhsy <- dyn$lm(log(consumption_2) ~ log(income_2) + lag(log(income_2), -1) + lag(log(consumption_2), -1))
summary(sf_dhsy)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_dhsy)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_dhsy, order=1)
bgtest(sf_dhsy, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_dhsy$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_dhsy, studentize = F)
#
########################################################################################
#
# 3.2.7 HUS
#
cons_inc_1 <- lag(log(consumption.m_1), -1) - lag(log(income.m_1), -1)
cons_inc_2 <- lag(log(consumption_2), -1) - lag(log(income_2), -1)
m2_inc_1 <- lag(log(m2_1), -1) - lag(log(income.m_1), -1)
m2_inc_2 <- lag(log(m2_2), -1) - lag(log(income_2), -1)
#
#..Odhad (1.41)..Vsledky (3.17/3.18)
# obdob ped hosp. kriz
sf_hus <- dyn$lm(diff(log(consumption.m_1)) ~ diff(log(income.m_1)) + cons_inc_1 + m2_inc_1)
# obdob po hosp. krizi
sf_hus <- dyn$lm(diff(log(consumption_2)) ~ diff(log(income_2)) + cons_inc_2 + m2_inc_2)
summary(sf_hus)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_hus)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_hus, order=1)
bgtest(sf_hus, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_hus$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_hus, studentize = F)
#
########################################################################################
#
# 3.2.8 Analza empirickho modelu
#
inflation_1 <- window(CR[ , "inflation"], start=c(1999,1), end=c(2008,2))
inflation_2 <- window(CR[ , "inflation"], start=c(2009,3), end=c(2016,4))
unemployment_1 <- window(CR[ , "unemployment"], start=c(1999,1), end=c(2008,2))
unemployment_2 <- window(CR[ , "unemployment"], start=c(2009,3), end=c(2016,4))
CPI_1 <- window(CR[ , "CPI"], start=c(1999,1), end=c(2008,2))
CPI_2 <- window(CR[ , "CPI"], start=c(2009,3), end=c(2016,4))
m3_rate_1 <- window(CR[ , "X3.month_rates"], start=c(1999,1), end=c(2008,2))
m3_rate_2 <- window(CR[ , "X3.month_rates"], start=c(2009,3), end=c(2016,4))
time_1 <- ts(c(1:38), start=c(1999,1), frequency = 4)
time_2 <- ts(c(1:30), start=c(2009,3), frequency = 4)
#
#..Vsledky (3.19/3.20)
# obdob ped hosp. kriz
sf_my1 <- dyn$lm(consumption_1 ~ lag(income_1, -1) + lag(consumption_1, -1))
summary(sf_my1)
# obdob po hosp. krizi
sf_my2 <- dyn$lm(consumption_2 ~ income_2 + unemployment_2 + inflation_2 + CPI_2 + time_2)
summary(sf_my2)
#
# Testy modelu:
require(lmtest) #install.packages("lmtest")
# Durbin-Watsonv test
dwtest(sf_my1)
# Breusch-Godfreyv test na sriovou korelaci
bgtest(sf_my1, order=1)
bgtest(sf_my1, order=3)
# Jarque-Bera test na normalitu rezidu
require(tseries) # install.packages("tseries")
jarque.bera.test(sf_my1$residuals)
# Breusch-Pagan test na heteroskedasticitu
bptest(sf_my1, studentize = F)
#
##
########################################################################################