#### Aplikace spotebn funkce na R ####
#
# Jaroslav Poncar
#
## Kapitola 4 Predikce
#
# R 1999Q1 - 2016Q4 (tvrtletn data)
# seznn oitn data
# v cench roku 2010
#
# vdaje na konenou spotebu domcnost (mil. K)
# disponibiln dchod domcnost (mil. K)
# mra nezamstnanosti (%)
#
rm(list=ls())
data_1 <- read.csv("cr_data.csv")
CR_1 <- ts(data_1, start=c(1999,1), frequency = 4)
CR_1
# Seznn oitn pomoc X-12-ARIMA #
require(stringi) # install.packages("stringi")
require(x12) # install.packages("x12")
# ?x12
x12path("c:/x12/x12a.exe") # cesta k programu x12a.exe
# ke staen na: http://www.census.gov/ts/TSMS/WIX12/winx12.zip
#
# Vdaje na spotebu
consx12 <- ts(CR_1[ , "consumption"], start=c(1999,1), frequency = 4)
cons.x <- new("x12Single",ts=consx12,tsName="cons")
cons.x <- x12(cons.x)
consumption_X12 <- cons.x@x12Output@d11
# Disponibiln dchod
incx12 <- ts(CR_1[ , "income"], start=c(1999,1), frequency = 4)
inc.x <- new("x12Single",ts=incx12,tsName="inc")
inc.x <- x12(inc.x)
income_X12 <- inc.x@x12Output@d11
# 
########################################################################################
#
# 4.1 Aplikace jednorozmrn metody prognzovn
#
# Predikce pomoc minulch hodnot
forecast <- cons.x@x12Output@forecast
forecast
plot(cons.x, trend = FALSE, sa = TRUE, forecast = TRUE)
#
########################################################################################
#
# 4.2 Aplikace vcerozmrn metody prognzovn
#
data <- read.csv("cr_data_all.csv")
CR <- ts(data, start=c(1999,1), frequency = 4)
CR
# Omezen potu pozorovn kvli promnn bohatstv
consumption <- window(CR[ , "consumption"], start=c(2008,1), end=c(2016,2))
income <- window(CR[ , "income"], start=c(2008,1), end=c(2016,2))
inflation <- window(CR[ , "inflation"], start=c(2008,1), end=c(2016,2))
unemployment <- window(CR[ , "unemployment"], start=c(2008,1), end=c(2016,2))
CPI <- window(CR[ , "CPI"], start=c(2008,1), end=c(2016,2))
m3_rate <- window(CR[ , "X3.month_rates"], start=c(2008,1), end=c(2016,2))
time <- ts(c(1:34), start=c(2008,1), frequency = 4)
#
require(dyn) # install.packages("dyn")
# Model (2.15)
sf_my1 <- dyn$lm(consumption ~ income + unemployment + time)
summary(sf_my1)
#
########################################################################################
#
# 4.2.2 Predikce ex post
#
consumption <- CR[ , "consumption"]
income <- CR[ , "income"]
wealth <- window(CR[ , "wealth"], start=c(2008,1), end=c(2016,2))
inflation <- window(CR[ , "inflation"], start=c(2008,1), end=c(2016,4))
unemployment <- window(CR[ , "unemployment"], start=c(2008,1), end=c(2016,4))
CPI <- window(CR[ , "CPI"], start=c(2008,1), end=c(2016,4))
m3_rate <- window(CR[ , "X3.month_rates"], start=c(2008,1), end=c(2016,4))
time <- ts(c(1:36), start=c(2008,1), frequency = 4)
#
#
require(zoo) # install.packages("zoo")
require(ggplot2) #install.packages("ggplot2")
require(forecast) #install.packages("forecast")
#
# Srovnn pozorovanch a pedpovzench hodnot spoteby
prediction <- predict(sf_my1, newdata = c(consumption,income,wealth,time,CPI,inflation,unemployment,m3_rate),  interval = "confidence")
prediction <- ts(prediction[c(37:72), ], start=c(2008,1), frequency = 4)
pred.plot.data <- cbind(consumption, prediction)
colnames(pred.plot.data) <- c("Consumption", "Fitted", "lwr", "upr")
pred.plot.data <- ts(pred.plot.data[37:72,], start=c(2008,1), frequency = 4)
#
plot.ts(pred.plot.data[,"lwr"],  col = 2, lwd = 1, lty = 3,
        ylab="Consumption forecasts and observations") # doln limit spolehlivosti predikce
        lines(pred.plot.data[,"upr"],  col = 2, lwd = 1, lty = 3) # horn limit spolehlivosti predikce
        lines(pred.plot.data[,"Fitted"],  col = 1, lwd = 2, lty = 1) # predikovan hodnoty
        lines(pred.plot.data[,"Consumption"],  col = "green", lwd = 1, lty = 1) # napozorovan hodnoty
        legend("topleft", legend=c("Observed Consumption", "Fitted"), pch=16, col=c("green", "black"))
#
# MSE, RMSE
#
Fitted <- pred.plot.data[,"Fitted"]
MSE <- mean((consumption - Fitted)^2, na.rm=T)
MSE
RMSE <- sqrt(MSE)
RMSE
#
########################################################################################
#
# 4.2.3 Predikce ex-ante
#   
forecast2 <- inc.x@x12Output@forecast
# Pedpov mry nezamstnanosti pomoc x12
x12path("c:/x12/x12a.exe")
unemploymentx12 <- ts(unemployment, start=c(2008,1), frequency = 4)
unemployment.x <- new("x12Single",ts=unemploymentx12,tsName="unemployment")
unemployment.x <- x12(unemployment.x)
forecast3 <- unemployment.x@x12Output@forecast
#
# Predikovan hodnoty a intervaly spolehlivosti
forecast2 # disponibiln dchod
forecast3 # mra nezamstnanosti
# 
# Pomoc koeficient z (2.15) a predikovanch hodnot dchodu (forecast2)
# a mry nezamstnanosti (forecast3) dopotny predikovan hodnoty 
# spoteby.
#
prediction <- predict(sf_my1, newdata = c(consumption,income,wealth,time,CPI,inflation,unemployment,m3_rate),  interval = "confidence")
prediction <- ts(prediction[c(37:72), ], start=c(2008,1), frequency = 4)
# write.csv2(prediction,"cr_prediction1.csv") 
# -> po pidn predikovanch hodnot spoteby -> cr_prediction.csv
prediction <- read.csv("cr_prediction.csv")
prediction <- ts(prediction, start=c(2008,1), frequency = 4)
prediction
#
# Srovnn pozorovanch a pedpovzench hodnot spoteby
pred.plot.data <- cbind(window(consumption, start=c(2008,1), end=c(2016,4)), prediction)
colnames(pred.plot.data) <- c("Consumption", "Fitted", "lwr", "upr")
pred.plot.data <- ts(pred.plot.data[1:40,], start=c(2008,1), frequency = 4)
#
plot.ts(pred.plot.data[,"lwr"],  col = 2, lwd = 1, lty = 3,
        ylab="Consumption forecasts and observations") # doln limit spolehlivosti predikce
        lines(pred.plot.data[,"upr"],  col = 2, lwd = 1, lty = 3) # horn limit spolehlivosti predikce
        lines(pred.plot.data[,"Fitted"],  col = 1, lwd = 2, lty = 1) # predikovan hodnoty
        lines(pred.plot.data[,"Consumption"],  col = "green", lwd = 1, lty = 1) # napozorovan hodnoty
        legend("topleft", legend=c("Observed Consumption", "Fitted"), pch=16, col=c("green", "black"))
#
########################################################################################
#
# Graf neoitnch hodnot vdaj na spotebu a jej predikce
#
# Pomoc seznnch faktor (cons_seas_fac) pro rok 2017 odhadnutmi x12
# pepotny vypotan predikovan hodnoty spoteby.
cons_seas_fac <- cons.x@x12Output@d10
cons_seas_fac
#
# Pvodn seznn neoitn hodnoty spoteby a predikovan hodnoty
# spoteby v cr_prediction_s.csv.
#
prediction_s <- read.csv("cr_prediction_s.csv")
prediction_s <- ts(prediction_s, start=c(2008,1), frequency = 4)
prediction_s
colnames(prediction_s) <- c("Consumption", "lwr", "upr")
# Graf
plot.ts(prediction_s[,"Consumption"], col = 1, lwd = 1, lty = 1,
        ylab="Consumption forecasts and observations") # spoteba
        lines(prediction_s[,"lwr"],  col = 2, lwd = 1, lty = 3) # doln limit spolehlivosti predikce
        lines(prediction_s[,"upr"],  col = 2, lwd = 1, lty = 3) # horn limit spolehlivosti predikce
prediction_s2 <- window(prediction_s, start=c(2017,1), end=c(2017,4))
colnames(prediction_s2) <- c("Consumption", "lwr", "upr")
prediction_s2 <- ts(prediction_s2[1:4,], start=c(2017,1), frequency = 4)
lines(prediction_s2[,"Consumption"], col = "blue", lwd = 2, lty = 3)
#
########################################################################################
#
# Srovnn predikc podle minulch hodnot a podle modelu (2.15)
#
# Vpoet predikce podle minulch hodnot z obdob 2008Q1-2016Q4 pomoc x12
x12path("c:/x12/x12a.exe")
CR_2 <- window(CR_1, start=c(2008,1), end=c(2016,4))
consx12_2 <- ts(CR_2[ , "consumption"], start=c(2008,1), frequency = 4)
cons.x_2 <- new("x12Single",ts=consx12_2,tsName="cons")
cons.x_2 <- x12(cons.x_2)
forecast_2 <- cons.x_2@x12Output@forecast
#
#
# Predikce podle modelu (2.15)
prediction_s2
# Predikce podle minulch hodnot z obdob 2008Q1-2016Q4
forecast_2
# Graf predikce podle minulch hodnot z obdob 2008Q1-2016Q4
plot(cons.x_2, trend = FALSE, sa = FALSE, forecast = TRUE)
#
#
##
########################################################################################